package com.vdocipher.flutter.vdoplayer;

import androidx.annotation.Nullable;

import com.vdocipher.aegis.media.ErrorDescription;
import com.vdocipher.aegis.media.MediaInfo;
import com.vdocipher.aegis.media.Track;
import com.vdocipher.aegis.player.VdoPlayer;

import java.util.ArrayList;
import java.util.HashMap;

public class MessageUtils {
    public static HashMap<String, Object> loadResultMap(@Nullable MediaInfo mediaInfo) {
        HashMap<String, Object> loadResultMap = new HashMap<>();
        if (mediaInfo == null) {
            loadResultMap.put("didLoad", false);
        } else {
            loadResultMap.put("didLoad", true);
            loadResultMap.put("mediaInfo", mediaInfoMap(mediaInfo));
            loadResultMap.put("playWhenReady", true);
        }
        return loadResultMap;
    }

    public static HashMap<String, Object> mediaInfoMap(MediaInfo mediaInfo) {
        HashMap<String, Object> mediaInfoMap = new HashMap<>();
        mediaInfoMap.put("mediaId", mediaInfo.mediaId);
        mediaInfoMap.put("type", mediaInfo.type);
        mediaInfoMap.put("title", mediaInfo.title);
        mediaInfoMap.put("description", mediaInfo.description);
        mediaInfoMap.put("duration", mediaInfo.duration);
        return mediaInfoMap;
    }

    public static ArrayList<HashMap<String, Object>> trackMapList(Track[] tracks) {
        ArrayList<HashMap<String, Object>> trackList = new ArrayList<>();
        for (Track track : tracks) {
            trackList.add(trackMap(track));
        }
        return trackList;
    }

    public static HashMap<String, Object> trackMap(Track track) {
        HashMap<String, Object> trackMap = new HashMap<>();
        trackMap.put("id", track.id);
        switch (track.type) {
            case Track.TYPE_AUDIO:
                trackMap.put("type", "audio");
                trackMap.put("language", track.language);
                trackMap.put("bitrate", track.bitrate);
                break;
            case Track.TYPE_VIDEO:
                trackMap.put("type", "video");
                trackMap.put("bitrate", track.bitrate);
                trackMap.put("width", track.width);
                trackMap.put("height", track.height);
                break;
            case Track.TYPE_CAPTIONS:
                trackMap.put("type", "subtitle");
                trackMap.put("language", track.language);
                break;
            default:
                break;
        }
        return trackMap;
    }

    public static HashMap<String, Object> errorInfoMap(ErrorDescription error) {
        HashMap<String, Object> errorInfoMap = new HashMap<>();
        errorInfoMap.put("errorCode", error.errorCode);
        errorInfoMap.put("errorMsg", error.errorMsg);
        errorInfoMap.put("httpStatusCode", error.httpStatusCode);
        return errorInfoMap;
    }

    public static String playerStateName(int vdoPlayerState) {
        switch (vdoPlayerState) {
            case VdoPlayer.STATE_IDLE:
                return "idle";
            case VdoPlayer.STATE_BUFFERING:
                return "buffering";
            case VdoPlayer.STATE_READY:
                return "ready";
            case VdoPlayer.STATE_ENDED:
                return "ended";
            default:
                return "unknown";
        }
    }
}
